@@ -364,7 +364,7 @@ public final class ACLPermission extends MailPermission {
             // }
             clone.acl = null;
             return clone;
-        } catch (final CloneNotSupportedException e) {
+        } catch (CloneNotSupportedException e) {
             LOG.error("", e);
             throw new RuntimeException("CloneNotSupportedException even though it's cloenable", e);
         }
