@@ -49,6 +49,7 @@
 
 package com.openexchange.imap;
 
+import static com.sun.mail.iap.ResponseCode.AUTHENTICATIONFAILED;
 import java.io.IOException;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
@@ -108,14 +109,12 @@ import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.api.MailConfig;
 import com.openexchange.mail.api.MailLogicTools;
 import com.openexchange.mail.config.MailProperties;
-import com.openexchange.mail.config.MailProxyConfig;
 import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.mime.MimeMailException;
 import com.openexchange.mail.mime.MimeMailExceptionCode;
 import com.openexchange.mail.mime.MimeSessionPropertyNames;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountStorageService;
-import com.openexchange.net.HostList;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 import com.openexchange.net.ssl.config.SSLConfigurationService;
 import com.openexchange.net.ssl.exception.SSLExceptionCode;
@@ -360,7 +359,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         if (folderStorage != null) {
             try {
                 folderStorage.releaseResources();
-            } catch (final OXException e) {
+            } catch (OXException e) {
                 LOG.error("Error while closing IMAP folder storage: {}", e.getMessage()).toString(), e));
             } finally {
                 folderStorage = null;
@@ -369,7 +368,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         if (messageStorage != null) {
             try {
                 messageStorage.releaseResources();
-            } catch (final OXException e) {
+            } catch (OXException e) {
                 LOG.error("Error while closing IMAP message storage: {}", e.getMessage()).toString(), e));
             } finally {
                 messageStorage = null;
@@ -389,7 +388,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             if (folderStorage != null) {
                 try {
                     folderStorage.releaseResources();
-                } catch (final OXException e) {
+                } catch (OXException e) {
                     LOG.error("Error while closing IMAP folder storage,", e);
                 }
             }
@@ -397,7 +396,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             if (null != messageStorage) {
                 try {
                     messageStorage.releaseResources();
-                } catch (final OXException e) {
+                } catch (OXException e) {
                     LOG.debug("Error while closing IMAP message storage.", e);
                 }
             }
@@ -473,14 +472,16 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             case OAUTH:
                 try {
                     IMAPConfig imapConfig = getIMAPConfig();
-                    return IMAPCapabilityAndGreetingCache.getCapabilities(new HostAndPort(IDNA.toASCII(imapConfig.getServer()), imapConfig.getPort()), imapConfig.isSecure(), imapConfig.getIMAPProperties()).containsKey("AUTH=XOAUTH2");
+                    boolean isPrimary = (imapConfig.getAccountId() == MailAccount.DEFAULT_ID);
+                    return IMAPCapabilityAndGreetingCache.getCapabilities(new HostAndPort(IDNA.toASCII(imapConfig.getServer()), imapConfig.getPort()), imapConfig.isSecure(), imapConfig.getIMAPProperties(), isPrimary).containsKey("AUTH=XOAUTH2");
                 } catch (IOException e) {
                     throw MailExceptionCode.IO_ERROR.create(e, e.getMessage());
                 }
             case OAUTHBEARER:
                 try {
                     IMAPConfig imapConfig = getIMAPConfig();
-                    return IMAPCapabilityAndGreetingCache.getCapabilities(new HostAndPort(IDNA.toASCII(imapConfig.getServer()), imapConfig.getPort()), imapConfig.isSecure(), imapConfig.getIMAPProperties()).containsKey("AUTH=OAUTHBEARER");
+                    boolean isPrimary = (imapConfig.getAccountId() == MailAccount.DEFAULT_ID);
+                    return IMAPCapabilityAndGreetingCache.getCapabilities(new HostAndPort(IDNA.toASCII(imapConfig.getServer()), imapConfig.getPort()), imapConfig.isSecure(), imapConfig.getIMAPProperties(), isPrimary).containsKey("AUTH=OAUTHBEARER");
                 } catch (IOException e) {
                     throw MailExceptionCode.IO_ERROR.create(e, e.getMessage());
                 }
@@ -539,7 +540,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                 retval = -1;
             }
             return retval;
-        } catch (final MessagingException e) {
+        } catch (MessagingException e) {
             throw MimeMailException.handleMessagingException(e, getMailConfig(), session);
         }
     }
@@ -599,10 +600,10 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                 } catch (@SuppressWarnings("unused") MessagingException e) {
                     // Ignore
                 }
-            } catch (final AuthenticationFailedException e) {
+            } catch (AuthenticationFailedException e) {
                 warnings.add(MailExceptionCode.PING_FAILED_AUTH.create(e, config.getServer(), config.getLogin()));
                 throw MimeMailException.handleMessagingException(e, config, session);
-            } catch (final MessagingException e) {
+            } catch (MessagingException e) {
                 if (MimeMailException.isSSLHandshakeException(e)) {
                     List<Object> displayArgs = new ArrayList<>(2);
                     displayArgs.add(SSLExceptionCode.extractArgument(e, "fingerprint"));
@@ -632,13 +633,13 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                 if (null != imapStore) {
                     try {
                         imapStore.close();
-                    } catch (final MessagingException e) {
+                    } catch (MessagingException e) {
                         LOG.warn("", e);
                     }
                 }
             }
             return true;
-        } catch (final OXException e) {
+        } catch (OXException e) {
             LOG.debug("Ping to IMAP server \"{}\" failed", config.getServer(), e);
             return false;
         }
@@ -702,17 +703,6 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                 }
             }
 
-            /*
-             * Remove proxy settings for whitelisted hosts
-             */
-            HostList nonProxyHosts = MailProxyConfig.getInstance().getImapNonProxyHostList();
-            if (nonProxyHosts.contains(getIMAPConfig().getImapServerAddress())) {
-                imapProps.remove("mail.imap.proxy.host");
-                imapProps.remove("mail.imap.proxy.port");
-                imapProps.remove("mail.imaps.proxy.host");
-                imapProps.remove("mail.imaps.proxy.host");
-            }
-
             /*
              * Get parameterized IMAP session
              */
@@ -754,8 +744,8 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             int maxCount = getIMAPConfig().getIMAPProperties().getMaxNumConnection();
             try {
                 imapStore = connectIMAPStore(maxCount);
-            } catch (final AuthenticationFailedException e) {
-                if (accountId != MailAccount.DEFAULT_ID) {
+            } catch (AuthenticationFailedException e) {
+                if (accountId != MailAccount.DEFAULT_ID && (Strings.isEmpty(e.getReason()) || AUTHENTICATIONFAILED.getName().equals(e.getReason()))) {
                     int accountId = this.accountId;
                     Session session = this.session;
                     AbstractTask<Void> task = new AbstractTask<Void>() {
@@ -764,7 +754,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                         public Void call() throws Exception {
                             MailAccountStorageService mass = Services.optService(MailAccountStorageService.class);
                             if (null != mass) {
-                                mass.incrementFailedMailAuthCount(accountId, session.getUserId(), session.getContextId(), null);
+                                mass.incrementFailedMailAuthCount(accountId, session.getUserId(), session.getContextId(), e);
                             }
                             return null;
                         }
@@ -779,7 +769,18 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                     }
                 }
                 throw oxe;
-            } catch (final MessagingException e) {
+            } catch (com.sun.mail.util.MailConnectException e) {
+                if (tmpDownEnabled) {
+                    /*
+                     * Remember a timed-out IMAP server on connect attempt
+                     */
+                    final Map<HostAndPort, Long> map = timedOutServers;
+                    if (null != map) {
+                        map.put(newHostAndPort(config), Long.valueOf(System.currentTimeMillis()));
+                    }
+                }
+                throw e;
+            } catch (MessagingException e) {
                 /*
                  * Check for a SocketTimeoutException
                  */
@@ -851,7 +852,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                     config.setAcl(false);
                 }
             }
-        } catch (final MessagingException e) {
+        } catch (MessagingException e) {
             throw MimeMailException.handleMessagingException(e, config, session);
         }
     }
@@ -937,7 +938,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         while (retryCount++ < maxRetryCount) {
             try {
                 return newConnectedImapStore(imapSession, server, port, login, pw, accountId);
-            } catch (final MessagingException e) {
+            } catch (MessagingException e) {
                 if (!(e.getNextException() instanceof ConnectQuotaExceededException)) {
                     throw e;
                 }
@@ -958,7 +959,9 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
          * Establish a new one...
          */
         IMAPStore imapStore = (IMAPStore) imapSession.getStore(PROTOCOL);
+        boolean isPrimary = false;
         if (MailAccount.DEFAULT_ID == accountId) {
+            isPrimary = true;
             boolean failedToSetClientParameters = true; // Pessimistic
             try {
                 IMAPClientParameters.setDefaultClientParameters(imapStore, session);
@@ -976,7 +979,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
          */
         if (null != preAuthStartTlsCap) {
             try {
-                Map<String, String> capabilities = IMAPCapabilityAndGreetingCache.getCapabilities(new HostAndPort(IDNA.toASCII(server), port), false, IMAPProperties.getInstance());
+                Map<String, String> capabilities = IMAPCapabilityAndGreetingCache.getCapabilities(new HostAndPort(IDNA.toASCII(server), port), false, IMAPProperties.getInstance(), isPrimary);
                 if (null != capabilities) {
                     preAuthStartTlsCap[0] = capabilities.containsKey("STARTTLS");
                 }
@@ -1318,6 +1321,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
          * Allow round-robin address election for primary IMAP account
          */
         if (config.getAccountId() == MailAccount.DEFAULT_ID) {
+            imapProps.put("mail.imap.primary", "true");
             boolean useMultipleAddresses = IMAPProperties.getInstance().isUseMultipleAddresses(userId, contextId);
             if (useMultipleAddresses) {
                 imapProps.put("mail.imap.multiAddress.enabled", "true");
@@ -1348,6 +1352,16 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         } else {
             imapProps.put("mail.imap.auth.mechanisms", "PLAIN LOGIN NTLM");
         }
+        /*
+         * Charset for "LOGIN" command. Default is UTF-8
+         */
+        {
+            IIMAPProperties imapConfProps = (IIMAPProperties) config.getMailProperties();
+            String imapAuthEnc = imapConfProps.getImapAuthEnc();
+            if (Strings.isNotEmpty(imapAuthEnc)) {
+                imapProps.put("mail.imap.login.encoding", imapAuthEnc.trim());
+            }
+        }
         /*
          * Check if a secure IMAP connection should be established
          */
