@@ -219,7 +219,7 @@ public abstract class AbstractIMAPCommand<T> {
             }
             try {
                 return abstractIMAPCommand.getReturnVal();
-            } catch (final MessagingException e) {
+            } catch (MessagingException e) {
                 final ProtocolException pe = new ProtocolException(e.getMessage());
                 pe.initCause(e);
                 throw pe;
