@@ -239,7 +239,7 @@ public final class ThreadableMapping {
             final String[] refs = current.getReferences();
             if (null != refs) {
                 for (final String reference : refs) {
-                    if (!isEmpty(reference)) {
+                    if (!com.openexchange.java.Strings.isEmpty(reference)) {
                         List<MailMessage> list = refsMap.get(reference);
                         if (null == list) {
                             list = new LinkedList<MailMessage>();
@@ -250,7 +250,7 @@ public final class ThreadableMapping {
                 }
             }
             final String messageId = current.getFirstHeader(hdrMessageId);
-            if (!isEmpty(messageId)) {
+            if (!com.openexchange.java.Strings.isEmpty(messageId)) {
                 List<MailMessage> list = messageIdMap.get(messageId);
                 if (null == list) {
                     list = new LinkedList<MailMessage>();
@@ -260,17 +260,4 @@ public final class ThreadableMapping {
             }
         }
     }
-
-    private static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
-        }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
-        }
-        return isWhitespace;
-    }
-
 }
