@@ -301,9 +301,9 @@ public final class Conversations {
                         // Handle remaining responses
                         protocol.notifyResponseHandlers(r);
                         return mails;
-                    } catch (final MessagingException e) {
+                    } catch (MessagingException e) {
                         throw new ProtocolException(e.getMessage(), e);
-                    } catch (final OXException e) {
+                    } catch (OXException e) {
                         throw new ProtocolException(e.getMessage(), e);
                     }
                 } else if (response.isBAD()) {
